; constants to hold cell alignment
#XLS_GeneralAlign      = 0
#XLS_LeftAlign         = 1
#XLS_CentreAlign       = 2
#XLS_RightAlign        = 3
#XLS_FillCell          = 4
#XLS_LeftBorder        = 8
#XLS_RightBorder       = 16
#XLS_TopBorder         = 32
#XLS_BottomBorder      = 64
#XLS_Shaded            = 128

; constants to handle selecting the font for the cell
;used by rgbAttr2
;bits 0-5 handle the *picture* formatting, not bold/underline etc...
;bits 6-7 handle the font number
#XLS_Font0             = 0
#XLS_Font1             = 64
#XLS_Font2             = 128
#XLS_Font3             = 192

;used by rgbAttr1
;bits 0-5 must be zero
;bit 6 locked/unlocked
;bit 7 hidden/not hidden
#XLS_CellNormal        = 0
#XLS_CellLocked        = 64
#XLS_CellHidden        = 128

; set up variables to hold the spreadsheet;s layout
#XLS_LeftMargin        = 38
#XLS_RightMargin       = 39
#XLS_TopMargin         = 40
#XLS_BottomMargin      = 41

; add these enums together. For example: xlsBold + xlsUnderline
#XLS_NoFormat          = 0
#XLS_Bold              = 1
#XLS_Italic            = 2
#XLS_Underline         = 4
#XLS_Strikeout         = 8

Structure XLS_FONT_RECORD
  opcode.w  ;49
  length.w  ;5+len(fontname)
  FontHeight.w
  FontAttributes1.b ; bit0 bold, bit1 italic, bit2 underline, bit3 strikeout, bit4-7 reserved
  FontAttributes2.b ; reserved - always 0
  FontNameLength.b
EndStructure

Structure XLS_PASSWORD_RECORD
  opcode.w  ;47
  length.w  ;len(password)
EndStructure

Structure XLS_HEADER_FOOTER_RECORD
  opcode.w  ;20 Header, 21 Footer
  length.w  ;1+len(text)
  TextLength.b
EndStructure

Structure XLS_PROTECT_SPREADSHEET_RECORD
  opcode.w  ;18
  length.w  ;2
  Protect.w
EndStructure

Structure XLS_FORMAT_COUNT_RECORD
  opcode.w  ;1f
  length.w  ;2
  Count.w
EndStructure

Structure XLS_FORMAT_RECORD
  opcode.w       ; 1e
  length.w       ; 1+len(format)
  FormatLength.b ; len(format) + followed by the Format-Picture
EndStructure

Structure XLS_COLWIDTH_RECORD
  opcode.w       ; 36
  length.w       ; 4
  col1.b         ;first column
  col2.b         ;last column
  ColumnWidth.w  ;at 1/256th of a character
EndStructure

;Beginning Of File record
Structure XLS_BEG_FILE_RECORD
  opcode.w
  length.w
  version.w
  ftype.w
EndStructure

;End Of File record
Structure XLS_END_FILE_RECORD
  opcode.w
  length.w
EndStructure

;true/false to print gridlines
Structure XLS_PRINT_GRIDLINES_RECORD
  opcode.w
  length.w
  PrintFlag.w
EndStructure

;Integer record
Structure XLS_tInteger
  opcode.w
  length.w
  Row.w      ; unsigned integer
  col.w
  rgbAttr1.b ; handles whether cell is hidden and/or locked
  rgbAttr2.b ; handles the Font# and Formatting assigned to this cell
  rgbAttr3.b ; handles the Cell Alignment/borders/shading
  intValue.w ; the actual integer value
EndStructure

;Number record
Structure XLS_tNumber
  opcode.w
  length.w
  Row.w
  col.w
  rgbAttr1.b
  rgbAttr2.b
  rgbAttr3.b
  NumberValue.d ; As Double  ;8 Bytes
EndStructure

;Label (Text) record
Structure XLS_tText
  opcode.w
  length.w
  Row.w
  col.w
  rgbAttr1.b
  rgbAttr2.b
  rgbAttr3.b
  TextLength.b
EndStructure

Structure XLS_MARGIN_RECORD_LAYOUT
  opcode.w
  length.w
  MarginValue.d ; As Double  ;8 bytes
EndStructure

Structure XLS_HPAGE_BREAK_RECORD
  opcode.w
  length.w
  NumPageBreaks.w
EndStructure

Structure XLS_DEF_ROWHEIGHT_RECORD
  opcode.w
  length.w
  RowHeight.w
EndStructure

Structure XLS_ROW_HEIGHT_RECORD
  opcode.w             ; 08
  length.w             ; should always be 16 bytes
  RowNumber.w
  FirstColumn.w
  LastColumn.w
  RowHeight.w          ; written to file as 1/20ths of a point
  internal.w
  DefaultAttributes.b  ;set to zero for no default attributes
  FileOffset.w
  rgbAttr1.b
  rgbAttr2.b
  rgbAttr3.b
EndStructure
; IDE Options = PureBasic v4.00 (Windows - x86)
; CursorPosition = 176
; FirstLine = 141
; Folding = -